@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileAccess.h,v 1.73 2002/01/21 16:25:14 lav Exp $ */
+/* $Id: FileAccess.h,v 1.77.2.1 2003/12/17 08:21:35 lav Exp $ */
 
 #ifndef FILEACCESS_H
 #define FILEACCESS_H
@@ -168,13 +168,15 @@ protected:
    char *error;
    int error_code;
    char *location;
+   char *suggested_filename;
+   void SetSuggestedFileName(const char *fn);
 
    FileAccess *next;
    static FileAccess *chain;
    FileAccess *FirstSameSite() { return NextSameSite(0); }
    FileAccess *NextSameSite(FileAccess *);
 
-   static int device_prefix_len(const char *path);
+   int device_prefix_len(const char *path);
 
    virtual ~FileAccess();
 
@@ -189,6 +191,7 @@ public:
    const char  *GetHome() { return home; }
    const char  *GetHostName() { return hostname; }
    const char  *GetUser() { return user; }
+   const char  *GetPassword() { return pass; }
    const char  *GetPort() { return portname; }
    const char  *GetConnectURL(int flags=0);
    const char  *GetFileURL(const char *file,int flags=0);
@@ -295,6 +298,7 @@ public:
    static bool NotSerious(int err);
 
    const char *GetNewLocation() { return location; }
+   const char *GetSuggestedFileName() { return suggested_filename; }
 
    void Reconfig(const char *);
 
@@ -339,7 +343,7 @@ public:
    int GetRetries() { return retries; }
    void SetRetries(int r) { retries=r; }
    time_t GetTryTime() { return try_time; }
-   void SetTryTime(time_t t) { try_time=t; }
+   void SetTryTime(time_t t);
 
    static void ClassInit();
 };
@@ -442,7 +446,7 @@ public:
 // cache of used sessions
 class SessionPool
 {
-   static const int pool_size=64;
+   enum { pool_size=64 };
    static FileAccess *pool[pool_size];
 
 public:
