@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileCopy.cc,v 1.95 2003/06/21 08:40:05 lav Exp $ */
+/* $Id: FileCopy.cc,v 1.96.2.2 2003/12/22 13:18:50 lav Exp $ */
 
 /* FileCopyPeer behaviour:
     1) when suspended, does nothing
@@ -178,6 +178,11 @@ int FileCopy::Do()
 	 SetError(_("seek failed"));
 	 return MOVED;
       }
+      if(get->GetSize()>0 && get->GetRealPos()>get->GetSize())
+      {
+	 get->SetSize(NO_SIZE_YET);
+	 get->SetDate(NO_DATE_YET);
+      }
       long lbsize=0;
       if(line_buffer)
 	 lbsize=line_buffer->Size();
@@ -322,7 +327,7 @@ int FileCopy::Do()
       if(put->Error())
 	 goto put_error;
       /* check if put position is correct */
-      if(put_eof_pos!=put->GetRealPos())
+      if(put_eof_pos!=put->GetRealPos() || put->GetSeekPos()==FILE_END)
       {
 	 state=DO_COPY;
 	 return MOVED;
@@ -884,6 +889,16 @@ void FileCopyPeerFA::OpenSession()
 	 return;
       }
    }
+   else // mode==PUT
+   {
+      if(e_size>=0 && size>=0 && seek_pos>=e_size)
+      {
+	 debug((10,"copy dst: seek past eof (seek_pos=%lld, size=%lld)\n",
+		  (long long)seek_pos,(long long)e_size));
+	 eof=true;
+	 return;
+      }
+   }
    session->Open(file,FAmode,seek_pos);
    session->SetFileURL(orig_url);
    if(mode==PUT)
@@ -1040,8 +1055,8 @@ int FileCopyPeerFA::Put_LL(const char *buf,int len)
    if(session->IsClosed())
       OpenSession();
 
-   off_t io_at=pos;
-   if(GetRealPos()!=io_at) // GetRealPos can alter pos.
+   off_t io_at=pos; // GetRealPos can alter pos, save it.
+   if(GetRealPos()!=io_at)
       return 0;
 
    if(len==0 && eof)
