@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: HttpDir.cc,v 1.73 2003/08/11 15:06:34 lav Exp $ */
+/* $Id: HttpDir.cc,v 1.73.2.4 2003/12/15 07:45:19 lav Exp $ */
 
 #include <config.h>
 #include "ascii_ctype.h"
@@ -196,7 +196,7 @@ const char *find_eol(const char *buf,int len,bool eof,int *eol_size)
    if(real_eol>buf && real_eol[-1]=='\r')
    {
       real_eol--;
-      *eol_size++;
+      (*eol_size)++;
    }
    return real_eol;
 }
@@ -355,7 +355,7 @@ static bool try_netscape_proxy(file_info &info,const char *str)
       debug("Netscape-Proxy 2.53 listing matched");
       return true;
    }
-   n=sscanf(str,"%3s %3s %d %2d:%2d:%2d %4d %s",
+   n=sscanf(str,"%3s %3s %d %2d:%2d:%2d %4d %30s",
 	    week_day,info.month_name,&info.day,
 	    &info.hour,&info.minute,&info.second,&info.year,info.size_str);
    if(n==7 || (n==8 && !is_ascii_digit(info.size_str[0])))
@@ -373,7 +373,7 @@ static bool try_squid_eplf(file_info &info,const char *str)
    info.clear();
 
    char week_day[4];
-   int n=sscanf(str,"%3s %3s %d %2d:%2d:%2d %4d %s",
+   int n=sscanf(str,"%3s %3s %d %2d:%2d:%2d %4d %30s",
 	    week_day,info.month_name,&info.day,
 	    &info.hour,&info.minute,&info.second,&info.year,info.size_str);
    if(n==8) // maybe squid's EPLF listing.
@@ -566,7 +566,7 @@ static bool try_wwwoffle_ftp(file_info &info,const char *buf,
       else if(info.perms[0]=='l')
       {
 	 info.is_sym_link=true;
-	 char *p=strstr(ext,"-&gt; ");
+	 const char *p=strstr(ext,"-&gt; ");
 	 if(p)
 	 {
 	    info.sym_link=xstrdup(p+6);
@@ -594,13 +594,13 @@ static bool try_csm_proxy(file_info &info,const char *str)
 
    int n;
    int status = false;
-   char additional_file_info[32];
+   char additional_file_info[33];
    int has_additional_file_info = false;
 
    memset(additional_file_info, '\0', sizeof (additional_file_info));
 
    // try to match hour:minute
-   if (5 <= (n = sscanf(str,"%d %3s %d %2d:%2d%32c",
+   if (5 <= (n = sscanf(str,"%lld %3s %d %2d:%2d%32s",
 	       &info.size, info.month_name, &info.day, &info.hour, &info.minute, additional_file_info))) {
       status = true;
       if (6 == n)
@@ -608,7 +608,7 @@ static bool try_csm_proxy(file_info &info,const char *str)
    } else {
        // try to match year instead of hour:minute
        info.clear();
-       if (4 <= (n = sscanf(str,"%d %3s %d %4d%32c",
+       if (4 <= (n = sscanf(str,"%lld %3s %d %4d%32s",
 		       &info.size, info.month_name, &info.day, &info.year, additional_file_info))) {
 	   status = true;
 	   if (5 == n)
@@ -616,13 +616,13 @@ static bool try_csm_proxy(file_info &info,const char *str)
        }
    }
 
-   if (true == status) {
+   if (status) {
       debug("csm_proxy listing matched");
-      sprintf(info.size_str, "%ld", info.size);
-      if (true == has_additional_file_info && strlen(additional_file_info)) {
-	  if (!strcmp("Symbolic Link", additional_file_info)) {
+      sprintf(info.size_str, "%lld", info.size);
+      if (has_additional_file_info && additional_file_info[0]) {
+	  if (!strncasecmp("Symbolic Link",additional_file_info,13)) {
 	      info.is_sym_link = true;
-	  } else if (!strcmp("Directory", additional_file_info)) {
+	  } else if (!strncasecmp("Directory",additional_file_info,9)) {
 	      info.is_directory = true;
 	  } else {
 	      // fprintf(stderr, "try_csm_proxy: |%s|\n", additional_file_info);
