@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: LocalAccess.cc,v 1.43 2003/05/23 07:04:11 lav Exp $ */
+/* $Id: LocalAccess.cc,v 1.43.2.2 2003/12/22 13:18:51 lav Exp $ */
 
 #include <config.h>
 #include <errno.h>
@@ -32,7 +32,6 @@
 
 #include "LocalAccess.h"
 #include "xmalloc.h"
-#include "xalloca.h"
 #include "xstring.h"
 #include "misc.h"
 #include "log.h"
@@ -466,6 +465,8 @@ int LocalAccess::Write(const void *vbuf,int len)
 
 int LocalAccess::StoreStatus()
 {
+   if(mode!=STORE)
+      return OK;
    if(!stream)
       return IN_PROGRESS;
    if(stream->getfd()==-1)
