@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: commands.cc,v 1.193 2003/06/16 11:32:51 lav Exp $ */
+/* $Id: commands.cc,v 1.195.2.1 2003/12/17 09:52:53 lav Exp $ */
 
 #include <config.h>
 
@@ -59,7 +59,6 @@
 #include "GetPass.h"
 #include "SignalHook.h"
 #include "FileFeeder.h"
-#include "xalloca.h"
 #include "bookmark.h"
 #include "log.h"
 #include "module.h"
@@ -240,7 +239,7 @@ const struct CmdExec::cmd_rec CmdExec::static_cmd_table[]=
    {"fg",      cmd_wait,   0,"wait"},
    {"find",    cmd_find,0,
 	 N_("Usage: find [OPTS] [directory]\n"
-	 "Print contents of specified directory of current directory recursively.\n"
+	 "Print contents of specified directory or current directory recursively.\n"
 	 "Directories in the list are marked with trailing slash.\n"
 	 "You can redirect output of this command.\n"
 	 " -d, --maxdepth=LEVELS  Descend at most LEVELS of directories.\n")},
@@ -593,7 +592,8 @@ Job *CmdExec::builtin_cd()
    xfree(old_cwd);
    old_cwd=xstrdup(session->GetCwd());
 
-   if (!verify_path || background)
+   if(!verify_path || background
+   || (!verify_path_cached && LsCache::IsDirectory(session,dir)==1))
    {
       session->Chdir(dir,false);
       if(slot)
@@ -724,8 +724,18 @@ Job *CmdExec::builtin_open()
    bool insecure=false;
    bool no_bm=false;
 
+   static struct option open_options[]=
+   {
+      {"port",required_argument,0,'p'},
+      {"user",required_argument,0,'u'},
+      {"execute",required_argument,0,'e'},
+      {"debug",optional_argument,0,'d'},
+      {"no-bookmark",no_argument,0,'B'},
+      {0,0,0,0}
+   };
+
    args->rewind();
-   while((c=args->getopt("u:p:e:dB"))!=EOF)
+   while((c=args->getopt_long("u:p:e:dB",open_options,0))!=EOF)
    {
       switch(c)
       {
@@ -1337,6 +1347,7 @@ const char *FileSetOutput::parse_argv(ArgV *a)
 	    if(!strcasecmp(optarg, "name")) sort = FileSet::BYNAME;
 	    else if(!strcasecmp(optarg, "size")) sort = FileSet::BYSIZE;
 	    else if(!strcasecmp(optarg, "date")) sort = FileSet::BYDATE;
+	    else if(!strcasecmp(optarg, "time")) sort = FileSet::BYDATE;
 	    else return _("invalid argument for `--sort'");
 	 } else if(!strcmp(cls_options[longopt].name, "filesize")) {
 	    size_filesonly = true;
